@@ -14,8 +14,12 @@ from gremlinapi.exceptions import (
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
-from gremlinapi.http_clients import get_gremlin_httpclient
+from gremlinapi.http_clients import (
+    get_gremlin_httpclient,
+    GremlinAPIHttpClient,
+)
 
+from typing import Union, Type
 
 log = logging.getLogger("GremlinAPI.client")
 
@@ -23,10 +27,14 @@ log = logging.getLogger("GremlinAPI.client")
 class GremlinAPIHalts(GremlinAPI):
     @classmethod
     @register_cli_action("halt_all_attacks", ("",), ("teamId", "body"))
-    def halt_all_attacks(cls, https_client=get_gremlin_httpclient(), **kwargs):
-        method = "POST"
-        data = cls._warn_if_not_json_body(**kwargs)
-        endpoint = cls._optional_team_endpoint("/halts", **kwargs)
-        payload = cls._payload(**{"headers": https_client.header(), "body": data})
+    def halt_all_attacks(
+        cls,
+        https_client: Type[GremlinAPIHttpClient] = get_gremlin_httpclient(),
+        **kwargs: dict
+    ) -> dict:
+        method: str = "POST"
+        data: dict = cls._warn_if_not_json_body(**kwargs)
+        endpoint: str = cls._optional_team_endpoint("/halts", **kwargs)
+        payload: dict = cls._payload(**{"headers": https_client.header(), "body": data})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
